require "prefabutil"

local assets =
{ 
    Asset("ANIM", "anim/hat_walrus.zip"),
}

local function OnEquip(inst, owner, data) 
    owner.AnimState:OverrideSymbol("swap_hat", "hat_walrus", "swap_hat") -- Replace our character's symbol(graphics) with hat's symbol
	
    owner.AnimState:Show("HAT") -- Basically: hide and show some layers of character's animation
    owner.AnimState:Show("HAIR_HAT")
    owner.AnimState:Hide("HAIR_NOHAT")
    owner.AnimState:Hide("HAIR")

    if owner:HasTag("player") then
        owner.AnimState:Hide("HEAD")
        owner.AnimState:Show("HEAD_HAT")
    end
    
    if owner.components.health ~= nil then
        owner.components.health.fire_damage_scale = owner.components.health.fire_damage_scale - TUNING.ARMORDRAGONFLY_FIRE_RESIST
    end
    
end


local function OnUnequip(inst, owner, data) 
	owner.AnimState:ClearOverrideSymbol("swap_hat") -- Clear character's symbol so it appears as if they don't have a hat equipped
	
    owner.AnimState:Hide("HAT")
    owner.AnimState:Hide("HAIR_HAT")
    owner.AnimState:Show("HAIR_NOHAT")
    owner.AnimState:Show("HAIR")

    if owner:HasTag("player") then
        owner.AnimState:Show("HEAD")
        owner.AnimState:Hide("HEAD_HAT")
    end
    
    if owner.components.health ~= nil then
        owner.components.health.fire_damage_scale = owner.components.health.fire_damage_scale + TUNING.ARMORDRAGONFLY_FIRE_RESIST
    end
    
end

local function OnOpen(inst)
    inst.sg:GoToState("open")
end

local function OnClose(inst)
    inst.sg:GoToState("close")
end

local function fn()
    local inst = CreateEntity()
    
    inst.entity:AddTransform()
    inst.entity:AddAnimState()
    inst.entity:AddSoundEmitter()
    inst.entity:AddMiniMapEntity()
    inst.entity:AddNetwork()

	inst.MiniMapEntity:SetIcon("piggyback.png")

    MakeInventoryPhysics(inst)

    inst.AnimState:SetBank("walrushat")
    inst.AnimState:SetBuild("hat_walrus")
    inst.AnimState:PlayAnimation("anim")

    inst:AddTag("generic_hat") -- tags are useful sometimes, no reason to not add one
	
	inst:AddTag("wildfireprotected")
	
	inst.entity:SetPristine()

    if not TheWorld.ismastersim then
        return inst
    end

	inst:AddComponent("insulator")
    inst.components.insulator:SetInsulation(TUNING.INSULATION_LARGE) --warmth for winter
    
    inst:AddComponent("inspectable")
    
    inst:AddComponent("tradable")
    
    inst:AddComponent("inventoryitem")
    inst.components.inventoryitem.imagename = "walrushat" --inventory image icon
    inst.components.inventoryitem.atlasname = "images/inventoryimages.xml"
	
	inst:AddComponent("container") --can be used as a container
	inst.components.container:WidgetSetup("icepack") --now it has the same inventory image and space as piggyback
    
    inst:AddComponent("equippable")
    inst.components.equippable.equipslot = EQUIPSLOTS.HEAD -- we'll wear this in our head slot
	inst.components.equippable:SetOnEquip(OnEquip)
    inst.components.equippable:SetOnUnequip(OnUnequip)
    inst.components.equippable.dapperness = TUNING.DAPPERNESS_HUGE --huge sanity boosy
	
	inst:AddComponent("waterproofer")
	inst.components.waterproofer:SetEffectiveness(TUNING.WATERPROOFNESS_HUGE) --a bit of waterproofness never hurts
	
	inst:AddComponent("burnable")
    inst.components.burnable.canlight = false
    inst.components.burnable.fxprefab = nil
    MakeHauntableLaunch(inst)

    return inst
end

return  Prefab("generic_hat", fn, assets)